@@ -2,7 +2,9 @@
 The main developer documentation for this API is located at 
 http://ordr.in/developers"""
 from hashlib import sha256
-import urllib3
+from google.appengine.api import urlfetch
+# import urllib3
+import pdb
 import json
 import re
 import urllib
@@ -38,11 +40,28 @@ class APIHelper(object):
       self.urls['user'] = "https://u-test.ordr.in"
       self.urls['order'] = "https://o-test.ordr.in"
 
-    pool = urllib3.PoolManager()
+    # pool = urllib3.PoolManager()
 
     def make_method(method_name):
         def method(url, data=None, headers=None):
-            return pool.request(method_name, url, fields=data, headers=headers)
+            if data:
+                data = urllib.urlencode(data)
+            # return pool.request(method_name, url, fields=data, headers=headers)
+            if method_name == 'GET':
+                meth = urlfetch.GET
+            if method_name == 'POST':
+                meth = urlfetch.POST
+            if method_name == 'PUT':
+                meth = urlfetch.PUT
+            if method_name == 'DELETE':
+                meth = urlfetch.DELETE
+
+            return urlfetch.fetch(url=url, payload=data, method=meth, headers=headers, validate_certificate=False, deadline=60)
+            # res = urlfetch.fetch(url=url, payload=data, method=meth, headers=headers)
+            # if res.status_code == 200:
+            #     return json.loads(res.content, 'utf-8')
+            # else:
+            #     pdb.set_trace()
         return method
 
     for method_name in 'GET POST PUT DELETE'.split(): 
@@ -66,7 +85,7 @@ class APIHelper(object):
       raise error.request_method(method)
     # r.raise_for_status()
     try:
-      result = json.loads(r.data)
+      result = json.loads(r.content)
     except ValueError:
       raise ApiInvalidResponseError(r.data)
     if '_error' in result and result['_error']:
